@@ -107,7 +107,7 @@ private:
     {
         ostringstream oss(Document::db_bootstrap);
 
-        return db->exec(oss);
+        return db->exec_local_wr(oss);
     };
 
     /**
