@@ -402,7 +402,7 @@ public:
      */
     const set<int>& get_prev_rediscovered_vms() const
     {
-        return prev_rediscovered_vms;
+        return *prev_rediscovered_vms;
     }
 
     /**
@@ -412,7 +412,7 @@ public:
      */
     void set_prev_rediscovered_vms(const set<int>& rediscovered_vms)
     {
-        prev_rediscovered_vms = rediscovered_vms;
+        *prev_rediscovered_vms = rediscovered_vms;
     }
 
 private:
@@ -453,26 +453,26 @@ private:
     /**
      *  The Share represents the logical capacity associated with the host
      */
-    HostShare       host_share;
+    HostShare host_share;
 
     /**
      * Tmp set of lost VM IDs. Used to give lost VMs one grace cycle, in case
      * they reappear.
      */
-    set<int>        tmp_lost_vms;
+    set<int> * tmp_lost_vms;
 
     /**
      * Tmp set of zombie VM IDs. Used to give zombie VMs one grace cycle, in
      * case they are cleaned.
      */
-    set<int>        tmp_zombie_vms;
+    set<int> * tmp_zombie_vms;
 
     /**
      * Set that stores the VMs reported as found from the poweroff state. This
      * is managed from outside the host to avoid deadlocks, as the current
      * VM state is needed
      */
-    set<int>        prev_rediscovered_vms;
+    set<int> * prev_rediscovered_vms;
 
     // -------------------------------------------------------------------------
     //  VM Collection
