@@ -23,6 +23,7 @@
 #include "ActionManager.h"
 #include "IPAMManagerDriver.h"
 #include "Attribute.h"
+#include "NebulaLog.h"
 
 //Forward definitions
 class IPAMRequest;
@@ -30,6 +31,47 @@ class IPAMRequest;
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
+class IPMAction : public ActionRequest
+{
+public:
+    enum Actions
+    {
+        REGISTER_ADDRESS_RANGE, /**< Register/Request a new IP network    */
+        ALLOCATE_ADDRESS,       /**< Request a specific IP (or range)     */
+        GET_ADDRESS,            /**< Request any free  IP (or range)      */
+        FREE_ADDRESS            /**< Frees a previously requested IP      */
+    };
+
+    IPMAction(Actions a, IPAMRequest *r):ActionRequest(ActionRequest::USER),
+        _action(a), _request(r){};
+
+    IPMAction(const IPMAction& o):ActionRequest(o._type), _action(o._action),
+        _request(o._request){};
+
+    Actions action() const
+    {
+        return _action;
+    }
+
+    IPAMRequest * request() const
+    {
+        return _request;
+    }
+
+    ActionRequest * clone() const
+    {
+        return new IPMAction(*this);
+    }
+
+private:
+    Actions       _action;
+
+    IPAMRequest * _request;
+};
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
 extern "C" void * ipamm_action_loop(void *arg);
 
 class IPAMManager : public MadManager, public ActionListener
@@ -44,22 +86,18 @@ public:
 
     ~IPAMManager(){};
 
-    enum Actions
-    {
-        REGISTER_ADDRESS_RANGE, /**< Register/Request a new IP network    */
-        ALLOCATE_ADDRESS,       /**< Request a specific IP (or range)     */
-        GET_ADDRESS,            /**< Request any free  IP (or range)      */
-        FREE_ADDRESS,           /**< Frees a previously requested IP      */
-        FINALIZE
-    };
-
     /**
      * Triggers specific action to the IPAM Manager. This function
      * wraps the ActionManager trigger function.
      *   @param action to the IPAM Manager action
      *   @param request an IPAM request
      */
-    void trigger(Actions action, IPAMRequest* request);
+    void trigger(IPMAction::Actions action, IPAMRequest* request)
+    {
+        IPMAction ipam_ar(action, request);
+
+        am.trigger(ipam_ar);
+    }
 
     /**
      *  This functions starts the associated listener thread, and creates a
@@ -91,7 +129,7 @@ public:
      */
     void finalize()
     {
-        am.trigger(ACTION_FINALIZE,0);
+        am.finalize();
     };
 
 private:
@@ -144,19 +182,6 @@ private:
                (MadManager::get(0, name, ipam_driver_name));
     };
 
-    /**
-     *  Function to execute the Manager action loop method within a new pthread
-     *  (requires C linkage)
-     */
-    friend void * ipamm_action_loop(void *arg);
-
-    /**
-     *  The action function executed when an action is triggered.
-     *    @param action the name of the action
-     *    @param arg arguments for the action function
-     */
-    void do_action(const std::string & action, void * arg);
-
     /**
      *  Register (or requests) a new address range to the IPAM.
      */
@@ -183,6 +208,29 @@ private:
      *    @return pointer to the IPAM driver to use, 0 on failure
      */
     const IPAMManagerDriver * setup_request(IPAMRequest * ir);
+
+    /**
+     *  Function to execute the Manager action loop method within a new pthread
+     *  (requires C linkage)
+     */
+    friend void * ipamm_action_loop(void *arg);
+
+    // -------------------------------------------------------------------------
+    // Action Listener interface
+    // -------------------------------------------------------------------------
+    void timer_action(const ActionRequest& ar)
+    {
+        check_time_outs_action();
+    };
+
+    void finalize_action(const ActionRequest& ar)
+    {
+        NebulaLog::log("IPM",Log::INFO,"Stopping IPAM Manager...");
+
+        MadManager::stop();
+    };
+
+    void user_action(const ActionRequest& ar);
 };
 
 #endif /*IPAM_MANAGER_H*/
