@@ -29,8 +29,7 @@ using namespace std;
 class VirtualMachineTemplate : public Template
 {
 public:
-    VirtualMachineTemplate():
-        Template(false,'=',"TEMPLATE"){};
+    VirtualMachineTemplate():Template(false,'=',"TEMPLATE"){};
 
     VirtualMachineTemplate(
             bool _replace_mode,
@@ -42,32 +41,6 @@ public:
 
     VirtualMachineTemplate(VirtualMachineTemplate& vmt):Template(vmt){};
 
-    /**
-     *  Checks the template for RESTRICTED ATTRIBUTES
-     *    @param rs_attr the first restricted attribute found if any
-     *    @return true if a restricted attribute is found in the template
-     */
-    bool check(string& rs_attr)
-    {
-        return Template::check(rs_attr, restricted_attributes);
-    };
-
-    /**
-     * Deletes all restricted attributes
-     */
-    void remove_restricted()
-    {
-        Template::remove_restricted(restricted_attributes);
-    };
-
-    /**
-     * Deletes all the attributes, except the restricted ones
-     */
-    void remove_all_except_restricted()
-    {
-        Template::remove_all_except_restricted(restricted_attributes);
-    };
-
     void set_xml_root(const char * _xml_root)
     {
         Template::set_xml_root(_xml_root);
@@ -85,26 +58,29 @@ public:
         target_name, const string& target_uname, const string& new_name,
         const string& new_uname);
 
+    // -------------------------------------------------------------------------
+    // Restricted attributes interface implementation
+    // -------------------------------------------------------------------------
+    virtual bool check_restricted(string& rs_attr, const Template* base)
+    {
+        return Template::check_restricted(rs_attr, base, restricted);
+    }
+
+    virtual bool check_restricted(string& rs_attr)
+    {
+        return Template::check_restricted(rs_attr, restricted);
+    }
+
+    static void parse_restricted(vector<const SingleAttribute *>& ra)
+    {
+        Template::parse_restricted(ra, restricted);
+    }
+
 private:
-
-    friend class VirtualMachinePool;
-
-    static vector<string> restricted_attributes;
-
-    bool has_restricted()
-    {
-        return restricted_attributes.size() > 0;
-    };
-
     /**
-     * Stores the attributes as restricted, these attributes will be used in
-     * VirtualMachineTemplate::check
-     * @param rattrs Attributes to restrict
+     *  Restricted attribute list for VirtualMachineTemplates
      */
-    static void set_restricted_attributes(vector<const SingleAttribute *>& rattrs)
-    {
-        Template::set_restricted_attributes(rattrs, restricted_attributes);
-    };
+    static std::map<std::string, std::set<std::string> > restricted;
 };
 
 /* -------------------------------------------------------------------------- */
