@@ -1208,7 +1208,8 @@ ONEDB_SHARED_MIGRATOR_FILES="src/onedb/shared/2.0_to_2.9.80.rb \
                              src/onedb/shared/4.11.80_to_4.90.0.rb \
                              src/onedb/shared/4.90.0_to_5.2.0.rb \
                              src/onedb/shared/5.2.0_to_5.3.80.rb \
-                             src/onedb/shared/5.3.80_to_5.4.0.rb"
+                             src/onedb/shared/5.3.80_to_5.4.0.rb \
+                             src/onedb/shared/5.4.0_to_5.4.1.rb"
 
 ONEDB_LOCAL_MIGRATOR_FILES="src/onedb/local/4.5.80_to_4.7.80.rb \
                             src/onedb/local/4.7.80_to_4.9.80.rb \
@@ -1218,7 +1219,8 @@ ONEDB_LOCAL_MIGRATOR_FILES="src/onedb/local/4.5.80_to_4.7.80.rb \
                             src/onedb/local/4.13.80_to_4.13.85.rb \
                             src/onedb/local/4.13.85_to_4.90.0.rb \
                             src/onedb/local/4.90.0_to_5.3.80.rb \
-                            src/onedb/local/5.3.80_to_5.4.0.rb"
+                            src/onedb/local/5.3.80_to_5.4.0.rb \
+                            src/onedb/local/5.4.0_to_5.4.1.rb"
 
 ONEDB_PATCH_FILES="src/onedb/patches/4.14_monitoring.rb \
                    src/onedb/patches/history_times.rb"
