@@ -17,11 +17,18 @@ fi
 case $ACTION in
 leader)
     sudo ip address add $IP dev $INTERFACE
-    arping -c 5 -A -I $INTERFACE ${IP%%/*}
+    for i in $(seq 5); do
+        sudo arping -c 1 -U -I $INTERFACE ${IP%%/*}
+        sleep 1
+        sudo arping -c 1 -A -I $INTERFACE ${IP%%/*}
+        sleep 1
+    done
+    oneflow-server start
     ;;
 
 follower)
     sudo ip address del $IP dev $INTERFACE
+    oneflow-server stop
     ;;
 
 *)
