@@ -17,7 +17,6 @@
 #include <climits>
 
 #include "AclManager.h"
-#include "NebulaLog.h"
 #include "PoolObjectAuth.h"
 
 /* -------------------------------------------------------------------------- */
@@ -34,16 +33,36 @@ const char * AclManager::db_bootstrap = "CREATE TABLE IF NOT EXISTS "
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-int AclManager::init_cb(void *nil, int num, char **values, char **names)
+static int get_lastOID(SqlDB * db)
 {
-    lastOID = -1;
+    ostringstream oss;
 
-    if ( values[0] != 0 )
-    {
-        lastOID = atoi(values[0]);
-    }
+    int _last_oid = -1;
 
-    return 0;
+    single_cb<int> cb;
+
+    cb.set_callback(&_last_oid);
+
+    oss << "SELECT last_oid FROM pool_control WHERE tablename='acl'";
+
+    db->exec_rd(oss, &cb);
+
+    cb.unset_callback();
+
+    return _last_oid;
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+static void set_lastOID(SqlDB * db, int lastOID)
+{
+    ostringstream oss;
+
+    oss << "REPLACE INTO pool_control (tablename, last_oid) VALUES ('acl',"
+        << lastOID << ")";
+
+    db->exec_wr(oss);
 }
 
 /* -------------------------------------------------------------------------- */
@@ -53,22 +72,13 @@ AclManager::AclManager(
     int     _zone_id,
     bool    _is_federation_slave,
     time_t  _timer_period)
-        :zone_id(_zone_id), db(_db), lastOID(-1),
-        is_federation_slave(_is_federation_slave), timer_period(_timer_period)
+        :zone_id(_zone_id), db(_db), is_federation_slave(_is_federation_slave),
+        timer_period(_timer_period)
 {
-    ostringstream oss;
+    int lastOID;
 
     pthread_mutex_init(&mutex, 0);
 
-    set_callback(static_cast<Callbackable::Callback> (&AclManager::init_cb));
-
-    oss << "SELECT last_oid FROM pool_control WHERE tablename='" << table
-            << "'";
-
-    db->exec(oss, this);
-
-    unset_callback();
-
     am.addListener(this);
 
     //Federation slaves do not need to init the pool
@@ -77,13 +87,15 @@ AclManager::AclManager(
         return;
     }
 
+    lastOID = get_lastOID(db);
+
     if (lastOID == -1)
     {
         // Add a default rules for the ACL engine
         string error_str;
 
         // Users in group USERS can create standard resources
-        // @1 VM+IMAGE+TEMPLATE+DOCUMENT/* CREATE *
+        // @1 VM+IMAGE+TEMPLATE+DOCUMENT+SECGROUP+VMGROUP/* CREATE *
         add_rule(AclRule::GROUP_ID |
                     1,
                  AclRule::ALL_ID |
@@ -91,7 +103,8 @@ AclManager::AclManager(
                     PoolObjectSQL::IMAGE |
                     PoolObjectSQL::TEMPLATE |
                     PoolObjectSQL::DOCUMENT |
-                    PoolObjectSQL::SECGROUP,
+                    PoolObjectSQL::SECGROUP |
+                    PoolObjectSQL::VMGROUP,
                  AuthRequest::CREATE,
                  AclRule::ALL_ID,
                  error_str);
@@ -131,7 +144,7 @@ extern "C" void * acl_action_loop(void *arg)
 
     aclm = static_cast<AclManager *>(arg);
 
-    aclm->am.loop(aclm->timer_period,0);
+    aclm->am.loop(aclm->timer_period);
 
     NebulaLog::log("ACL",Log::INFO,"ACL Manager stopped.");
 
@@ -173,7 +186,7 @@ void AclManager::finalize()
 {
     if (is_federation_slave)
     {
-        am.trigger(ACTION_FINALIZE,0);
+        am.finalize();
     }
     else
     {
@@ -564,6 +577,8 @@ int AclManager::add_rule(long long user, long long resource, long long rights,
 
     lock();
 
+    int lastOID = get_lastOID(db);
+
     if (lastOID == INT_MAX)
     {
         lastOID = -1;
@@ -607,7 +622,7 @@ int AclManager::add_rule(long long user, long long resource, long long rights,
     acl_rules.insert( make_pair(rule->user, rule) );
     acl_rules_oids.insert( make_pair(rule->oid, rule) );
 
-    update_lastOID();
+    set_lastOID(db, lastOID);
 
     unlock();
 
@@ -636,7 +651,6 @@ error_common:
     error_str = oss.str();
 
     delete rule;
-    lastOID--;
 
     unlock();
 
@@ -1094,25 +1108,9 @@ int AclManager::bootstrap(SqlDB * _db)
 {
     ostringstream oss(db_bootstrap);
 
-    return _db->exec(oss);
+    return _db->exec_local_wr(oss);
 }
 
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-
-void AclManager::update_lastOID()
-{
-    // db->escape_str is not used for 'table' since its name can't be set in
-    // any way by the user, it is hardcoded.
-
-    ostringstream oss;
-
-    oss << "REPLACE INTO pool_control (tablename, last_oid) VALUES ("
-        << "'" <<   table       << "',"
-        <<          lastOID     << ")";
-
-    db->exec(oss);
-}
 
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
@@ -1186,7 +1184,7 @@ int AclManager::select()
     acl_rules.clear();
     acl_rules_oids.clear();
 
-    rc = db->exec(oss,this);
+    rc = db->exec_rd(oss,this);
 
     unlock();
 
@@ -1212,7 +1210,7 @@ int AclManager::insert(AclRule * rule, SqlDB * db)
         <<  rule->rights    << ","
         <<  rule->zone      << ")";
 
-    rc = db->exec(oss);
+    rc = db->exec_wr(oss);
 
     return rc;
 }
@@ -1229,7 +1227,7 @@ int AclManager::drop(int oid)
     oss << "DELETE FROM " << table << " WHERE "
         << "oid=" << oid;
 
-    rc = db->exec(oss);
+    rc = db->exec_wr(oss);
 
     return rc;
 }
@@ -1261,24 +1259,3 @@ int AclManager::dump(ostringstream& oss)
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void AclManager::do_action(const string &action, void * arg)
-{
-    if (action == ACTION_TIMER)
-    {
-        select();
-    }
-    else if (action == ACTION_FINALIZE)
-    {
-        NebulaLog::log("ACL",Log::INFO,"Stopping ACL Manager...");
-    }
-    else
-    {
-        ostringstream oss;
-        oss << "Unknown action name: " << action;
-
-        NebulaLog::log("ACL", Log::ERROR, oss);
-    }
-}
-
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
