@@ -127,7 +127,7 @@ class OpenNebula::LdapAuth
 
     def find_user(name)
         begin
-            filter = "#{@options[:user_field]}=#{escape(name)}"
+            filter = Net::LDAP::Filter.eq(@options[:user_field], escape(name))
 
             result = @ldap.search(
                 :base       => @options[:base],
@@ -155,10 +155,11 @@ class OpenNebula::LdapAuth
     end
 
     def is_in_group?(user, group)
+        username = user.first.force_encoding(Encoding::UTF_8)
         result=@ldap.search(
                     :base   => group,
                     :attributes => [@options[:group_field]],
-                    :filter => "(#{@options[:group_field]}=#{user.first})")
+                    :filter => "(#{@options[:group_field]}=#{username})")
 
         if result && result.first
             true
@@ -196,7 +197,7 @@ class OpenNebula::LdapAuth
             filter = "(#{@options[:group_field]}=#{@user[@options[:user_field]].first})"
             @ldap.search(
                 :base       => @options[:base],
-                :attributes => "dn",
+                :attributes => [ "dn" ],
                 :filter     => filter
             ) do |entry|
                 if @mapping[entry.dn]
@@ -228,4 +229,3 @@ private
       string.gsub(FILTER_ESCAPE_RE) { |char| "\\" + FILTER_ESCAPES[char] }
     end
 end
-
