@@ -192,6 +192,20 @@ class OneVMHelper < OpenNebulaHelper::OneHelper
         end
     end
 
+    def retrieve_snapshot_id(vm_id, id)
+        vm = retrieve_resource(vm_id)
+        vm.info
+
+        if !/\A\d+\z/.match(id)
+            ids = vm.retrieve_elements("/VM/TEMPLATE/SNAPSHOT[NAME='#{id}']/SNAPSHOT_ID")
+            return [-1, "#{id} not found or duplicated"] if ids.nil? || ids.size > 1
+        else
+            return [0, id.to_i]
+        end
+
+        [0, ids[0].to_i]
+    end
+
     def format_pool(options)
         config_file = self.class.table_conf
 
