@@ -19,7 +19,7 @@
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-vector<string> ImageTemplate::restricted_attributes;
+std::map<std::string, std::set<std::string> > ImageTemplate::restricted;
 
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
