@@ -924,7 +924,15 @@ void  LifeCycleManager::epilog_success_action(int vid)
     vm->set_etime(the_time);
 
     vm->set_vm_info();
+    
+    VectorAttribute * graphics = vm->get_template_attribute("GRAPHICS");
 
+    if ( graphics != 0 && (graphics->vector_value("PORT", port) == 0))
+    {
+        graphics->remove("PORT");
+        clpool->release_vnc_port(vm->get_cid(), port);
+    }
+    
     vmpool->update_history(vm);
 
     vmpool->update(vm);
@@ -933,13 +941,6 @@ void  LifeCycleManager::epilog_success_action(int vid)
 
     hpool->del_capacity(vm->get_hid(), vm->get_oid(), cpu, mem, disk, pci);
 
-    const VectorAttribute * graphics = vm->get_template_attribute("GRAPHICS");
-
-    if ( graphics != 0 && (graphics->vector_value("PORT", port) == 0))
-    {
-        clpool->release_vnc_port(vm->get_cid(), port);
-    }
-
     //----------------------------------------------------
 
     dm->trigger(action,vid);
