@@ -14,7 +14,6 @@
 # limitations under the License.                                             #
 #--------------------------------------------------------------------------- #
 
-
 require 'opennebula/pool_element'
 
 module OpenNebula
@@ -343,16 +342,6 @@ module OpenNebula
 
             self.info
 
-            # Add dsid as VM template parameter for vcenter
-            if ds_id!=-1 &&
-               !self["/VM/USER_TEMPLATE/PUBLIC_CLOUD/TYPE"].nil? &&
-               self["/VM/USER_TEMPLATE/PUBLIC_CLOUD/TYPE"].downcase == "vcenter"
-                ds = OpenNebula::Datastore.new_with_id(ds_id, @client)
-                rc = ds.info
-                return rc if OpenNebula.is_error?(rc)
-               self.update("VCENTER_DS_REF=#{ds['/DATASTORE/VCENTER_DS_REF']}", true)
-            end
-
             return call(VM_METHODS[:deploy],
                         @pe_id,
                         host_id.to_i,
