@@ -26,14 +26,22 @@ int VirtualMachinePoolXML::set_up()
 
     if ( rc == 0 )
     {
+        map<int, ObjectXML*>::iterator it;
+
         if (objects.empty())
         {
             return -2;
         }
 
+        vm_resources.clear();
+
+        for ( it = objects.begin(); it != objects.end(); ++it )
+        {
+            vm_resources.add_resource(it->first);
+        } 
+
         if (NebulaLog::log_level() >= Log::DDDEBUG)
         {
-            map<int,ObjectXML*>::iterator it;
 
             oss << "Pending/rescheduling VM and capacity requirements:" << endl;
 
