@@ -113,5 +113,31 @@ module OpenNebulaJSON
 
              str
          end
+
+         def hash_to_str(template_hash, delete_values)
+            for del in delete_values
+                template_hash.delete(del)
+            end
+
+            if !template_hash.empty?
+                template_str = ""
+                template_hash.collect do |key,value|
+                    if value.kind_of?(Array)
+                        template_str << key.to_s.upcase << " = \["
+                        for obj in value
+                            if obj.kind_of?(Hash)
+                                obj.collect do |key,value|
+                                    template_str << key.to_s.upcase << " = \""<< value.to_s << "\"\n"
+                                end
+                            end
+                        end
+                        template_str << "\]\n"
+                    else
+                        template_str << key.to_s.upcase << " = \""<< value.to_s << "\"\n"
+                    end
+                end
+            end
+            return template_str
+        end
      end
 end
