@@ -38,6 +38,7 @@ define(function(require) {
       User            = require('./opennebula/user'),
       Vdc             = require('./opennebula/vdc'),
       Vm              = require('./opennebula/vm'),
+      VMGroup         = require('./opennebula/vmgroup'),
       Zone            = require('./opennebula/zone'),
       VirtualRouter   = require('./opennebula/virtualrouter');
       MarketPlace     = require('./opennebula/marketplace');
@@ -82,6 +83,7 @@ define(function(require) {
     'User': User,
     'Vdc': Vdc,
     'VM': Vm,
+    'VMGroup': VMGroup,
     'Zone': Zone,
     'VirtualRouter': VirtualRouter,
     'MarketPlace': MarketPlace,
