@@ -45,7 +45,9 @@ define(function(require) {
     parentTab: "storage-top-tab",
     listHeader: Locale.tr("Files"),
     infoHeader: Locale.tr("File"),
-    subheader: '',
+    subheader: '<span>\
+        <span class="total_files"/> <small>'+Locale.tr("TOTAL")+'</small>\
+      </span>',
     resource: 'File',
     buttons: Buttons,
     actions: Actions,
