@@ -57,7 +57,8 @@ define(function(require) {
           {"sWidth": "35px", "aTargets": [0]},
           {"bVisible": true, "aTargets": SunstoneConfig.tabTableColumns(tabId)},
           {"bVisible": false, "aTargets": ['_all']},
-          {"sType": "file-size", "aTargets": [ 6 ] }
+          {"sType": "file-size", "aTargets": [ 6 ] },
+          {"sType": "num", "aTargets": [1, 11]}
       ]
     }
 
