@@ -75,7 +75,9 @@ define(function(require) {
           {"sWidth": "35px", "aTargets": [0]},
           {"bVisible": true, "aTargets": SunstoneConfig.tabTableColumns(TAB_NAME)},
           {"bVisible": false, "aTargets": ['_all']},
-          {"sType": "file-size", "aTargets": [ 6 ] }
+          {"sType": "file-size", "aTargets": [ 6 ]},
+          {"sType": "date-euro", "aTargets": [ 9 ]},
+          {"sType": "num", "aTargets": [1, 11]}
       ]
     }
 
@@ -105,6 +107,8 @@ define(function(require) {
       "you_selected_multiple": Locale.tr("You selected the following appliances:")
     }
 
+    this.totalApps = 0;
+
     this.conf.searchDropdownHTML = SearchDropdown({tableId: this.dataTableId});
     this.searchColumn = SEARCH_COLUMN;
 
@@ -114,6 +118,8 @@ define(function(require) {
   Table.prototype = Object.create(TabDataTable.prototype);
   Table.prototype.constructor = Table;
   Table.prototype.elementArray = _elementArray;
+  Table.prototype.preUpdateView = _preUpdateView;
+  Table.prototype.postUpdateView = _postUpdateView;
 
   return Table;
 
@@ -127,6 +133,8 @@ define(function(require) {
     var state = OpenNebulaMarketPlaceApp.stateStr(element.STATE);
     var zone = OpenNebulaZone.getName(element.ZONE_ID);
 
+    this.totalApps++;
+
     var search = {
       NAME:           element.NAME,
       UNAME:          element.UNAME,
@@ -150,7 +158,7 @@ define(function(require) {
         Humanize.sizeFromMB(element.SIZE),
         state,
         OpenNebulaMarketPlaceApp.typeStr(element.TYPE),
-        Humanize.prettyTime(element.REGTIME),
+        Humanize.prettyTimeDatatable(element.REGTIME),
         element.MARKETPLACE,
         zone,
         (LabelsUtils.labelsStr(element[TEMPLATE_ATTR])||''),
@@ -167,4 +175,12 @@ define(function(require) {
 
     return l;
   }
+
+  function _preUpdateView() {
+    this.totalApps = 0;
+  }
+
+  function _postUpdateView() {
+    $(".total_apps").text(this.totalApps);
+  }
 });
