@@ -74,7 +74,8 @@ define(function(require) {
           {"sWidth": "35px", "aTargets": [0]},
           {"sWidth": "250px", "aTargets": [5]},
           {"bVisible": true, "aTargets": SunstoneConfig.tabTableColumns(TAB_NAME)},
-          {"bVisible": false, "aTargets": ['_all']}
+          {"bVisible": false, "aTargets": ['_all']},
+          {"sType": "num", "aTargets": [1, 6, 8]}
       ]
     }
 
@@ -104,12 +105,16 @@ define(function(require) {
     this.conf.searchDropdownHTML = SearchDropdown({tableId: this.dataTableId});
     this.searchColumn = SEARCH_COLUMN;
 
+    this.totalMarkets = 0;
+
     TabDataTable.call(this);
   };
 
   Table.prototype = Object.create(TabDataTable.prototype);
   Table.prototype.constructor = Table;
   Table.prototype.elementArray = _elementArray;
+  Table.prototype.preUpdateView = _preUpdateView;
+  Table.prototype.postUpdateView = _postUpdateView;
 
   return Table;
 
@@ -119,6 +124,7 @@ define(function(require) {
 
   function _elementArray(element_json) {
     var element = element_json[XML_ROOT];
+    this.totalMarkets++;
 
     var zone = OpenNebulaZone.getName(element.ZONE_ID);
 
@@ -156,4 +162,12 @@ define(function(require) {
 
     return l;
   }
+
+  function _preUpdateView() {
+    this.totalMarkets = 0;
+  }
+
+  function _postUpdateView() {
+    $(".total_markets").text(this.totalMarkets);
+  }
 });
