@@ -58,7 +58,9 @@ define(function(require) {
           {"bSortable": false, "aTargets": ["check"]},
           {"sWidth": "35px", "aTargets": [0]},
           {"bVisible": true, "aTargets": SunstoneConfig.tabTableColumns(tabId)},
-          {"bVisible": false, "aTargets": ['_all']}
+          {"bVisible": false, "aTargets": ['_all']},
+          {"sType": "date-euro", "aTargets": [ 5 ]},
+          {"sType": "num", "aTargets": [1]}
       ]
     }
 
@@ -118,7 +120,7 @@ define(function(require) {
         element.NAME,
         element.UNAME,
         element.GNAME,
-        Humanize.prettyTime(element.REGTIME),
+        Humanize.prettyTimeDatatable(element.REGTIME),
         (LabelsUtils.labelsStr(element[TEMPLATE_ATTR])||''),
         btoa(unescape(encodeURIComponent(JSON.stringify(search))))
     ];
