@@ -105,19 +105,31 @@ define(function(require) {
         $("[wizard_field]", imageContext).prop('wizard_field_disabled', true);
       }
     });
-
     $("[wizard_field]", imageContext).prop('wizard_field_disabled', false);
     $("[wizard_field]", volatileContext).prop('wizard_field_disabled', true);
 
     // Volatile Type FS hides Format, Type SWAP displays Format
-    $("select#TYPE", volatileContext).change(function() {
+    $("select#TYPE_KVM", volatileContext).change(function() {
       var value = $(this).val();
       switch (value){
         case "fs":
-          $("select#FORMAT", volatileContext).parent().show();
+          $("select#FORMAT_KVM", volatileContext).parent().show();
           break;
         case "swap":
-          $("select#FORMAT", volatileContext).parent().hide();
+          $("select#FORMAT_KVM", volatileContext).parent().hide();
+          break;
+      }
+    });
+
+    // Volatile Type FS hides Format, Type SWAP displays Format
+    $("select#TYPE_VCENTER", volatileContext).change(function() {
+      var value = $(this).val();
+      switch (value){
+        case "fs":
+          $("select#FORMAT_VCENTER", volatileContext).parent().show();
+          break;
+        case "swap":
+          $("select#FORMAT_VCENTER", volatileContext).parent().hide();
           break;
       }
     });
@@ -139,17 +151,37 @@ define(function(require) {
       selectedContext = $("div.image",  context);
     } else {
       selectedContext = $("div.volatile",  context);
+      var typeKvm = $("#TYPE_KVM", context).val();
+      var typeVcenter = $("#TYPE_VCENTER", context).val();
+      var type = "fs";
+      if(typeKvm != "fs"){
+        type = typeKvm;
+      } else if (typeVcenter != "fs"){
+        type = typeVcenter;
+      }
 
-      if ($("select#TYPE", selectedContext).val() == "swap")
+      if (type == "swap")
       {
         $("select#FORMAT", selectedContext).val("");
       }
     }
 
     var tmpl = WizardFields.retrieve(selectedContext);
+    if(type){
+      tmpl.TYPE = type;
+    }
 
-    if(tmpl.SIZE){
+    if(tmpl.SIZE != undefined && $(".mb_input_unit", context).val() == "GB"){
       tmpl.SIZE = tmpl.SIZE * 1024;
+      tmpl.SIZE = tmpl.SIZE.toString();
+    }
+    var formatKvm = $("#FORMAT_KVM", context).val();
+    var formatVcenter = $("#FORMAT_VCENTER", context).val();
+
+    if(formatKvm != "raw"){
+      tmpl.FORMAT = formatKvm;
+    } else if (formatVcenter != "raw"){
+      tmpl.FORMAT = formatVcenter;
     }
 
     if($("input[name='" + this.diskTabId + "']:checked", context).val() == "image" && !tmpl["IMAGE"] && !tmpl["IMAGE_ID"]){
