@@ -289,8 +289,19 @@ define(function(require) {
             // Check if it's volatile
             if (disk.IMAGE_ID &&
                  StateActions.enabledStateAction("VM.disk_saveas", that.element.STATE, that.element.LCM_STATE)) {
-              actions += '<a href="VM.disk_saveas" class="disk_saveas nowrap" >\
-              <i class="fa fa-save fa-fw" title="Saveas"></i></a> &emsp;';//+ Locale.tr("Save as") + ';'
+              if(Array.isArray(that.element.HISTORY_RECORDS.HISTORY)){
+                var historyLenght = that.element.HISTORY_RECORDS.HISTORY.length - 1;
+                if(that.element.LCM_STATE != "3" || that.element.HISTORY_RECORDS.HISTORY[historyLenght].VM_MAD != "vcenter"){
+                  actions += '<a href="VM.disk_saveas" class="disk_saveas nowrap" >\
+              <i class="fa fa-save fa-fw" title="Saveas"></i></a> &emsp;';
+                }
+              } else {
+                if(that.element.LCM_STATE != "3" || that.element.HISTORY_RECORDS.HISTORY.VM_MAD != "vcenter"){
+                  actions += '<a href="VM.disk_saveas" class="disk_saveas nowrap" >\
+              <i class="fa fa-save fa-fw" title="Saveas"></i></a> &emsp;';
+                }
+              }
+              //+ Locale.tr("Save as") + ';'
             }
           }
 
@@ -311,10 +322,20 @@ define(function(require) {
             }
           }
           
-          if (Config.isTabActionEnabled("vms-tab", "VM.resize")) {
-            if (StateActions.enabledStateAction("VM.resize", that.element.STATE, that.element.LCM_STATE)) {
-              actions += ('<a class="disk_resize nowrap" >\
-              <i class="fa fa-expand fa-fw" title="Resize"></i></a>');
+          if (Config.isTabActionEnabled("vms-tab", "VM.disk_resize")) {
+            if (StateActions.enabledStateAction("VM.disk_resize", that.element.STATE, that.element.LCM_STATE) && !disk.CONTEXT) {
+              if(Array.isArray(that.element.HISTORY_RECORDS.HISTORY)){
+                var historyLenght = that.element.HISTORY_RECORDS.HISTORY.length - 1;
+                if(that.element.LCM_STATE != "3" || that.element.HISTORY_RECORDS.HISTORY[historyLenght].VM_MAD != "vcenter"){
+                  actions += ('<a class="disk_resize nowrap" >\
+                  <i class="fa fa-expand fa-fw" title="Resize"></i></a>');
+                }
+              } else {
+                if(that.element.LCM_STATE != "3" || that.element.HISTORY_RECORDS.HISTORY.VM_MAD != "vcenter"){
+                  actions += ('<a class="disk_resize nowrap" >\
+                  <i class="fa fa-expand fa-fw" title="Resize"></i></a>');
+                }
+              }
             }
           }
         }
@@ -582,10 +603,19 @@ define(function(require) {
       });
     }
     if (Config.isTabActionEnabled("vms-tab", "VM.resize")) {
-    context.off('click', '.disk_sresize');
+    context.off('click', '.disk_resize');
       context.on('click', '.disk_resize', function() {
         var disk_id = $(this).parents('tr').attr('disk_id');
-        var disk_size = that.element.TEMPLATE.DISK.SIZE*1024; //to MB
+        var disk_size = "";
+        if(Array.isArray(that.element.TEMPLATE.DISK)){
+          $.each(that.element.TEMPLATE.DISK, function(){
+            if (this.DISK_ID == disk_id){
+              disk_size = this.SIZE * 1024;
+            }
+          });
+        } else {
+            disk_size = that.element.TEMPLATE.DISK.SIZE * 1024;
+        }
         var dialog = Sunstone.getDialog(DISK_RESIZE_DIALOG_ID);
         dialog.setParams(
           { element: that.element,
