@@ -49,7 +49,9 @@ define(function(require) {
     parentTab: "instances-top-tab",
     listHeader: Locale.tr("Virtual Routers"),
     infoHeader: Locale.tr("Virtual Router"),
-    subheader: '',
+    subheader: '<span>\
+        <span class="total_routers"/> <small>'+Locale.tr("TOTAL")+'</small>\
+      </span>',
     resource: 'VirtualRouter',
     buttons: Buttons,
     actions: Actions,
