@@ -56,7 +56,8 @@ define(function(require) {
           {"bSortable": false, "aTargets": ["check"]},
           {"sWidth": "35px", "aTargets": [0]},
           {"bVisible": true, "aTargets": SunstoneConfig.tabTableColumns(TAB_NAME)},
-          {"bVisible": false, "aTargets": ['_all']}
+          {"bVisible": false, "aTargets": ['_all']},
+          {"sType": "num", "aTargets": [1]}
       ]
     };
 
@@ -78,6 +79,8 @@ define(function(require) {
       "you_selected_multiple": Locale.tr("You selected the following virtual routers:")
     };
 
+    this.totalRouters = 0;
+
     this.conf.searchDropdownHTML = SearchDropdown({tableId: this.dataTableId});
     this.searchColumn = SEARCH_COLUMN;
 
@@ -87,6 +90,8 @@ define(function(require) {
   Table.prototype = Object.create(TabDataTable.prototype);
   Table.prototype.constructor = Table;
   Table.prototype.elementArray = _elementArray;
+  Table.prototype.preUpdateView = _preUpdateView;
+  Table.prototype.postUpdateView = _postUpdateView;
 
   return Table;
 
@@ -96,6 +101,7 @@ define(function(require) {
 
   function _elementArray(element_json) {
     var element = element_json[XML_ROOT];
+    this.totalRouters++;
 
     var search = {
       NAME:  element.NAME,
@@ -115,4 +121,12 @@ define(function(require) {
         btoa(unescape(encodeURIComponent(JSON.stringify(search))))
     ];
   }
+
+  function _preUpdateView() {
+    this.totalRouters = 0;
+  }
+
+  function _postUpdateView() {
+    $(".total_routers").text(this.totalRouters);
+  }
 });
