@@ -23,15 +23,27 @@ define(function(require) {
   var VectorAttributeRowTemplateHTML = require('hbs!./custom-tags-table/vector-attribute-row');
   var TemplateUtils = require('utils/template-utils');
   var WizardFields = require('utils/wizard-fields');
+  var Sunstone = require('sunstone');
 
   function _html(){
     return TemplateHTML();
   }
 
-  function _setup(context){
+  function _setup(context, hide_vector_button = false, resourceType = undefined, element = undefined, elementID = undefined){
     context.off("click", ".add_custom_tag");
     context.on("click", ".add_custom_tag", function(){
       $("tbody.custom_tags", context).append(RowTemplateHTML());
+      if(hide_vector_button){
+        $(".change_to_vector_attribute", context).hide();
+        $(".custom_tag_value",context).focusout(function(){
+          var key = $(".custom_tag_key",this.parentElement.parentElement).val();
+          if(!element.CAPACITY){
+            element.CAPACITY = {};
+          }
+          element.CAPACITY[key] = this.value;
+          Sunstone.runAction(resourceType+".update_template",elementID, TemplateUtils.templateToString(element));
+        });
+      }
     });
 
     context.off("click", ".add_vector_attribute");
@@ -58,6 +70,13 @@ define(function(require) {
     context.on("click", "tbody.custom_tags i.remove-tab", function(){
       var tr = $(this).closest('tr');
       tr.remove();
+      if(hide_vector_button){
+        var key = $(".custom_tag_key",this.parentElement.parentElement.parentElement).val()
+        if(element.CAPACITY && element.CAPACITY[key]){
+          delete element.CAPACITY[key];
+          Sunstone.runAction(resourceType+".update_template",elementID, TemplateUtils.templateToString(element));
+        }
+      }
     });
   }
 
