@@ -87,7 +87,7 @@ define(function(require) {
     var order_inputs = "";
 
     $('.user_input_attrs tbody tr').each(function(key, value){
-      order_inputs += $(".user_input_name", $(this)).val() + ",";
+      order_inputs += $(".user_input_name", $(this)).val().toUpperCase() + ",";
     });
 
     this.order = order_inputs.slice(0,-1);
@@ -364,7 +364,6 @@ define(function(require) {
       if(opts.defaults.INPUTS_ORDER){
         var order = opts.defaults.INPUTS_ORDER;
         var orderJSON = order.split(",");
-
         $.each(orderJSON, function(key, value){
           var orderValue = value;
           $.each(input_attrs, function(index, custom_attr) {
@@ -381,6 +380,18 @@ define(function(require) {
             }
           });
         });
+      } else {
+        $.each(input_attrs, function(index, custom_attr) {
+          $(".instantiate_user_inputs", div).append(
+            '<div class="row">' +
+              '<div class="large-12 large-centered columns">' +
+                '<label>' +
+                  TemplateUtils.htmlEncode(custom_attr.description) +
+                  _attributeInput(custom_attr) +
+                '</label>' +
+              '</div>' +
+            '</div>');
+        });
       }
     }
 
@@ -561,7 +572,7 @@ define(function(require) {
 
     } else if (attr_gb.type == "number"){
       attr_gb.type = "number-float";
-      attr_gb.step = "1";
+      attr_gb.step = "0.1";
     }
 
     div.html(
