@@ -27,6 +27,7 @@ define(function(require) {
   var UniqueId = require('utils/unique-id');
   var VCenterCommon = require('./vcenter-common');
   var Sunstone = require('sunstone');
+  var Tips = require('utils/tips');
 
   var TemplateHTML = require('hbs!./common/html');
   var RowTemplate = require('hbs!./templates/row');
@@ -112,16 +113,48 @@ define(function(require) {
               if (element.rp && element.rp !== '') {
                 opts.resourcePool = UserInputs.unmarshall(element.rp);
                 opts.resourcePool.params = opts.resourcePool.params.split(",");
-                $.each(opts.resourcePool.params, function(){
+               /* $.each(opts.resourcePool.params, function(){
                   $("#available_rps_" + opts.id + " [value ='" + this + "']").mousedown(function(e) {
                     e.preventDefault();
                     $(this).prop('selected', !$(this).prop('selected'));
                     return false;
                   });
-                });
+                });*/
               }
 
               var trow = $(RowTemplate(opts)).appendTo(tbody);
+              Tips.setup(trow);
+
+              $("#modify_rp_" + opts.id).change(function(){
+                var val = $("#modify_rp_" + opts.id).val();
+                if (val == "default"){
+                  $("#div_rp_" + opts.id).hide();
+                } else if (val == "fixed"){
+                  $("#div_rp_" + opts.id).show();
+                  $("#available_rps_" + opts.id).attr("multiple", false);
+                } else {
+                  $("#div_rp_" + opts.id).show();
+                  $("#available_rps_" + opts.id).attr("multiple", true);
+                }
+              });
+
+              $("#linked_clone_"+opts.id).on("change", function(){
+                if ($("#linked_clone_"+opts.id).is(":checked")){
+                  $("#create_"+opts.id).show();
+                } else {
+                  $("#create_"+opts.id).hide();
+                  $("#create_copy_"+opts.id).prop("checked", false);
+                  $("#name_"+opts.id).hide();
+                }
+              });
+
+              $("#create_copy_"+opts.id).on("change", function(){
+                if ($("#create_copy_"+opts.id).is(":checked")){
+                  $("#name_"+opts.id).show();
+                } else {
+                  $("#name_"+opts.id).hide();
+                }
+              });
 
               $('.check_item', trow).data("import_data", element);
             });
@@ -353,13 +386,13 @@ define(function(require) {
               });
           }
 
-          if (disks_and_nets[index].type == "EXISTING_NIC") {
+          if (disks_and_nets[index] != undefined && disks_and_nets[index].type == "EXISTING_NIC") {
             template += disks_and_nets[index].network_tmpl;
             ++index;
             getNext();
           }
 
-          if (disks_and_nets[index].type === "DUPLICATED_NIC") {
+          if (disks_and_nets[index] != undefined && disks_and_nets[index].type == "DUPLICATED_NIC") {
             var network_id = duplicated_nics[disks_and_nets[index].network_name];
 
             template += "NIC=[\n";
@@ -369,8 +402,6 @@ define(function(require) {
             ++index;
             getNext();
           }
-
-
       }
     }
     getNext();
@@ -392,20 +423,39 @@ define(function(require) {
         var rpInput = $(".vcenter_rp_input", row_context);
         if (rpInput.length > 0) {
           var rpModify = $('.modify_rp', rpInput).val();
-          var rpInitial = $('.initial_rp', rpInput).val();
           var rpParams = "";
+          var linkedClone = $('.linked_clone', rpInput).prop("checked");
+          var createCopy = $('.create_copy', rpInput).prop("checked");
+          var templateName = $('.template_name', rpInput).val();
+
+          var vcenter_ref = $(this).data("import_data").vcenter_ref;
+          if(linkedClone){
+            var linked = true;
+            if(createCopy && templateName != ""){
+              var copy = true;
+              var template_name  = templateName;
+            } else {
+              var copy = false;
+              var template_name = "";
+            }
+          } else {
+            var template_name  = "";
+            var linked = false;
+            var copy = false;
+          }
+
           $.each($('.available_rps option:selected', rpInput), function(){
             rpParams += $(this).val() + ",";
           });
           var rpParams = rpParams.slice(0,-1);
 
-          if (rpModify === 'fixed' && rpInitial !== '') {
-            attrs.push('VCENTER_RESOURCE_POOL="' + rpInitial + '"');
+          if (rpModify === 'fixed' && rpParams!== '') {
+            attrs.push('VCENTER_RESOURCE_POOL="' + rpParams + '"');
           } else if (rpModify === 'list' && rpParams !== '') {
             var rpUserInputs = UserInputs.marshall({
                 type: 'list',
                 description: Locale.tr("Which resource pool you want this VM to run in?"),
-                initial: rpInitial,
+                initial: "",
                 params: rpParams
               });
 
@@ -428,11 +478,8 @@ define(function(require) {
               var template_json = {
                 "vmtemplate": { "template_raw": template }
               };
-
-              var vcenter_ref = $(this).data("import_data").vcenter_ref;
-
               OpenNebulaTemplate.create({
-                timeout: true,
+                timeout: false,
                 data: template_json,
                 success: function(request, response) {
                    VCenterCommon.importLoading({
@@ -445,7 +492,12 @@ define(function(require) {
                    $.ajax({
                     url: path,
                     type: "GET",
-                    data: {timeout: false},
+                    data: {
+                      timeout: false,
+                      use_linked_clones: linked,
+                      create_copy: copy,
+                      template_name: template_name
+                    },
                     headers: {
                       "X-VCENTER-USER": that.opts.vcenter_user,
                       "X-VCENTER-PASSWORD": that.opts.vcenter_password,
@@ -453,8 +505,29 @@ define(function(require) {
                     },
                     dataType: "json",
                     success: function(response){
-                      var disks_and_nets = response.disks.concat(response.nics)
-                      import_images_and_nets(disks_and_nets, row_context, template_id)
+                      var disks_and_nets = response.disks.concat(response.nics);
+                      var template_json = {
+                        "vmtemplate": { "template_raw": response.one }
+                      };
+                      if(response.create_copy){
+                        OpenNebulaTemplate.del({
+                          timeout: true,
+                          data : {
+                            id : template_id
+                          },
+                          success: function(){
+                            OpenNebulaTemplate.create({
+                              timeout: false,
+                              data: template_json,
+                              success: function(request, response){
+                                import_images_and_nets(disks_and_nets, row_context, response.VMTEMPLATE.ID);
+                              }
+                            });
+                          }
+                        });
+                      } else {
+                        import_images_and_nets(disks_and_nets, row_context, template_id);
+                      }
                     },
                     error: function(response){
                       VCenterCommon.importFailure({
