@@ -295,33 +295,42 @@ void Quotas::quota_del(QuotaType type, int uid, int gid, Template * tmpl)
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void Quotas::ds_del(map<int, Template *>& ds_quotas)
+void Quotas::ds_del_recreate(int uid, int gid, vector<Template *>& ds_quotas)
 {
     Nebula&     nd    = Nebula::instance();
     ImagePool * ipool = nd.get_ipool();
 
-    map<int, Template *>::iterator it;
+    vector<Template *>::iterator it;
 
     for (it = ds_quotas.begin(); it != ds_quotas.end(); it++)
     {
-        int        image_id = it->first;
-        Template * tmpl     = it->second;
+        int        image_id = -1;
+        Template * tmpl = *it;
 
-        if ( tmpl == 0 )
+        bool vm_owner, img_owner;
+
+        tmpl->get("IMAGE_ID", image_id);
+        tmpl->get("VM_QUOTA", vm_owner);
+        tmpl->get("IMG_QUOTA", img_owner);
+
+        if ( img_owner )
         {
-            continue;
+            Image* img = ipool->get(image_id, true);
+
+            if(img != 0)
+            {
+                int img_uid = img->get_uid();
+                int img_gid = img->get_gid();
+
+                img->unlock();
+
+                quota_del(DATASTORE, img_uid, img_gid, tmpl);
+            }
         }
 
-        Image* img = ipool->get(image_id, true);
-
-        if(img != 0)
+        if ( vm_owner )
         {
-            int img_uid = img->get_uid();
-            int img_gid = img->get_gid();
-
-            img->unlock();
-
-            quota_del(DATASTORE, img_uid, img_gid, tmpl);
+            quota_del(DATASTORE, uid, gid, tmpl);
         }
 
         delete tmpl;
