@@ -343,6 +343,8 @@ string& History::to_xml(string& xml, bool database) const
 
 int History::rebuild_attributes()
 {
+    vector<xmlNodePtr> content;
+
     int int_action;
     int rc = 0;
 
@@ -375,6 +377,24 @@ int History::rebuild_attributes()
 
     action = static_cast<VMAction>(int_action);
 
+    // -------------------------------------------------------------------------
+    ObjectXML::get_nodes("/HISTORY/VM", content);
+
+    if (!content.empty())
+    {
+        ObjectXML vm_info_xml(content[0]);
+
+        ostringstream oss;
+
+        oss << vm_info_xml;
+
+        vm_info = oss.str();
+
+        ObjectXML::free_nodes(content);
+
+        content.clear();
+    }
+
     non_persistent_data();
 
     if (rc != 0)
