@@ -517,6 +517,8 @@ int VirtualMachine::select(SqlDB * db)
             History * hp;
 
             hp = new History(oid, i);
+            history_records[i] = hp;
+
             rc = hp->select(db);
 
             if ( rc != 0)
@@ -524,8 +526,6 @@ int VirtualMachine::select(SqlDB * db)
                 goto error_previous_history;
             }
 
-            history_records[i] = hp;
-
             if ( i == last_seq )
             {
                 history = hp;
@@ -2128,10 +2128,16 @@ int VirtualMachine::from_xml(const string &xml_str)
     if ( xpath(last_seq,"/VM/HISTORY_RECORDS/HISTORY/SEQ", -1) == 0 && 
             last_seq != -1 )
     {
+        history_records.resize(last_seq + 1);
+
+        for (int i=0; i <= last_seq; ++i)
+        {
+            history_records[i] = 0;
+        }
+
         history = new History(oid, last_seq);
 
-        history_records.resize(history->seq + 1);
-        history_records[history->seq] = history;
+        history_records[last_seq] = history;
     }
 
     // -------------------------------------------------------------------------
@@ -2217,6 +2223,8 @@ int VirtualMachine::replace_template(
         bool            keep_restricted,
         string&         error)
 {
+    string ra;
+
     VirtualMachineTemplate * new_tmpl =
             new VirtualMachineTemplate(false,'=',"USER_TEMPLATE");
 
@@ -2232,17 +2240,23 @@ int VirtualMachine::replace_template(
         return -1;
     }
 
-    if (keep_restricted)
+    if (user_obj_template != 0)
     {
-        new_tmpl->remove_restricted();
-
-        if (user_obj_template != 0)
+        if (keep_restricted && new_tmpl->check_restricted(ra, user_obj_template))
         {
-            user_obj_template->remove_all_except_restricted();
+            error = "Tried to change restricted attribute: " + ra;
 
-            new_tmpl->merge(user_obj_template);
+            delete new_tmpl;
+            return -1;
         }
     }
+    else if (keep_restricted && new_tmpl->check_restricted(ra))
+    {
+        error = "Tried to set restricted attribute: " + ra;
+
+        delete new_tmpl;
+        return -1;
+    }
 
     delete user_obj_template;
 
@@ -2261,6 +2275,7 @@ int VirtualMachine::append_template(
 {
     VirtualMachineTemplate * new_tmpl =
             new VirtualMachineTemplate(false,'=',"USER_TEMPLATE");
+    string rname;
 
     if ( new_tmpl == 0 )
     {
@@ -2274,18 +2289,26 @@ int VirtualMachine::append_template(
         return -1;
     }
 
-    if (keep_restricted)
-    {
-        new_tmpl->remove_restricted();
-    }
-
     if (user_obj_template != 0)
     {
+        if (keep_restricted && new_tmpl->check_restricted(rname, user_obj_template))
+        {
+            error ="User Template includes a restricted attribute " + rname;
+            delete new_tmpl;
+            return -1;
+        }
         user_obj_template->merge(new_tmpl);
+
         delete new_tmpl;
     }
     else
     {
+        if (keep_restricted && new_tmpl->check_restricted(rname))
+        {
+            error ="User Template includes a restricted attribute " + rname;
+            delete new_tmpl;
+            return -1;
+        }
         user_obj_template = new_tmpl;
     }
 
