@@ -167,6 +167,7 @@ int LibVirtDriver::deployment_description_kvm(
     string  script = "";
     string  model  = "";
     string  ip     = "";
+    string  vrouter_ip = "";
     string  filter = "";
 
     string  i_avg_bw = "";
@@ -871,6 +872,8 @@ int LibVirtDriver::deployment_description_kvm(
         ip     = nic[i]->vector_value("IP");
         filter = nic[i]->vector_value("FILTER");
 
+        vrouter_ip = nic[i]->vector_value("VROUTER_IP");
+
         i_avg_bw  = nic[i]->vector_value("INBOUND_AVG_BW");
         i_peak_bw = nic[i]->vector_value("INBOUND_PEAK_BW");
         i_peak_kb = nic[i]->vector_value("INBOUND_PEAK_KB");
@@ -956,8 +959,15 @@ int LibVirtDriver::deployment_description_kvm(
                 file << "\t\t\t<filterref filter="
                          << one_util::escape_xml_attr(*the_filter) << ">\n"
                      << "\t\t\t\t<parameter name='IP' value="
-                         << one_util::escape_xml_attr(ip) << "/>\n"
-                     << "\t\t\t</filterref>\n";
+                         << one_util::escape_xml_attr(ip) << "/>\n";
+
+                if ( !vrouter_ip.empty() )
+                {
+                    file << "\t\t\t\t<parameter name='IP' value="
+                            << one_util::escape_xml_attr(vrouter_ip) << "/>\n";
+                }
+
+                file << "\t\t\t</filterref>\n";
             }
         }
 
