@@ -661,7 +661,7 @@ void VirtualMachineManagerDriver::protocol(const string& message) const
             string monitor_str;
             getline(is, monitor_str);
 
-            process_poll(vm, monitor_str, true);
+            process_poll(vm, monitor_str);
         }
         else
         {
@@ -684,10 +684,7 @@ void VirtualMachineManagerDriver::protocol(const string& message) const
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void VirtualMachineManagerDriver::process_poll(
-        int id,
-        const string &monitor_str,
-        bool update_db)
+void VirtualMachineManagerDriver::process_poll(int id,const string& monitor_str)
 {
     // Get the VM from the pool
     VirtualMachine* vm = Nebula::instance().get_vmpool()->get(id,true);
@@ -697,7 +694,7 @@ void VirtualMachineManagerDriver::process_poll(
         return;
     }
 
-    process_poll(vm, monitor_str, update_db);
+    process_poll(vm, monitor_str);
 
     vm->unlock();
 }
@@ -705,10 +702,8 @@ void VirtualMachineManagerDriver::process_poll(
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void VirtualMachineManagerDriver::process_poll(
-        VirtualMachine* vm,
-        const string&   monitor_str,
-        bool            update_db)
+void VirtualMachineManagerDriver::process_poll(VirtualMachine* vm,
+    const string& monitor_str)
 {
     char state;
 
@@ -723,20 +718,15 @@ void VirtualMachineManagerDriver::process_poll(
 
     if (vm->get_state() == VirtualMachine::ACTIVE)
     {
-        int rc = vm->update_info(monitor_str);
-
-        if ( update_db )
+        if (vm->update_info(monitor_str) == 0)
         {
-            if ( rc == 0)
-            {
-                vmpool->update_history(vm);
+            vmpool->update_history(vm);
 
-                vmpool->update_monitoring(vm);
-            }
-
-            vmpool->update(vm);
+            vmpool->update_monitoring(vm);
         }
 
+        vmpool->update(vm);
+
         VirtualMachineMonitorInfo &minfo = vm->get_info();
 
         state = minfo.remove_state();
