@@ -77,35 +77,31 @@ class Network
 
         one_tmp = {}
 
-        if unmanaged
-            if unmanaged == "wild"
-                network_import_name = "#{network_name} [VM #{vm_or_template_name}]"
-            end
-
-            if unmanaged == "template"
-                network_import_name = "#{network_name} [#{vm_or_template_name} - Template #{template_id}]"
-            end
+        if unmanaged && unmanaged == "wild"
+            network_import_name = "#{network_name} [VM #{vm_or_template_name}]"
         else
-            full_name = "#{network_name} - #{ccr_name.tr(" ", "_")} [#{vcenter_instance_name} - #{dc_name}]_#{cluster_location}"
+            hash_name = "#{network_name} - #{ccr_name.tr(" ", "_")} [#{vcenter_instance_name} - #{dc_name}]_#{cluster_location}"
             sha256 = Digest::SHA256.new
-            network_hash = sha256.hexdigest(full_name)[0..11]
+            network_hash = sha256.hexdigest(hash_name)[0..11]
             network_import_name = "#{network_name} - #{ccr_name.tr(" ", "_")} [#{vcenter_instance_name} - #{dc_name}]_#{network_hash}"
         end
-        one_tmp[:name] = network_name
-        one_tmp[:import_name] = network_import_name
-        one_tmp[:bridge] = network_name
-        one_tmp[:type] = network_type
-        one_tmp[:cluster] = ccr_name
+
+        one_tmp[:name]             = network_name
+        one_tmp[:import_name]      = network_import_name
+        one_tmp[:bridge]           = network_name
+        one_tmp[:type]             = network_type
+        one_tmp[:cluster]          = ccr_name
         one_tmp[:cluster_location] = cluster_location
-        one_tmp[:vcenter_ccr_ref] = ccr_ref
-        one_tmp[:one_cluster_id] = cluster_id
+        one_tmp[:vcenter_ccr_ref]  = ccr_ref
+        one_tmp[:one_cluster_id]   = cluster_id
+
         one_tmp[:one] = to_one(network_import_name, network_name, network_ref, network_type,
-                             ccr_ref, vcenter_uuid, unmanaged, template_ref, dc_ref)
+                             ccr_ref, vcenter_uuid, unmanaged, template_ref, dc_ref, template_id)
         return one_tmp
     end
 
     def self.to_one(network_import_name, network_name, network_ref, network_type,
-                    ccr_ref, vcenter_uuid, unmanaged, template_ref, dc_ref)
+                    ccr_ref, vcenter_uuid, unmanaged, template_ref, dc_ref, template_id)
 
         template = "NAME=\"#{network_import_name}\"\n"\
                    "BRIDGE=\"#{network_name}\"\n"\
@@ -114,39 +110,26 @@ class Network
                    "VCENTER_NET_REF=\"#{network_ref}\"\n"\
                    "VCENTER_INSTANCE_ID=\"#{vcenter_uuid}\"\n"
 
+        if unmanaged == "wild"
+            template += "VCENTER_FROM_WILD=\"#{template_id}\"\n"
+            template += "OPENNEBULA_MANAGED=\"NO\"\n"
+        end
+
         template += "VCENTER_CCR_REF=\"#{ccr_ref}\"\n" if !unmanaged
 
-        template += "OPENNEBULA_MANAGED=\"NO\"\n" if unmanaged
         template += "VCENTER_TEMPLATE_REF=\"#{template_ref}\"\n" if template_ref
 
         return template
     end
 
     def self.get_network_type(device)
-        if device.backing.network.instance_of?(RbVmomi::VIM::DistributedVirtualPortgroup)
+        if device.backing.is_a? RbVmomi::VIM::VirtualEthernetCardDistributedVirtualPortBackingInfo
             return "Distributed Port Group"
         else
             return "Port Group"
         end
     end
 
-    def self.get_unmanaged_vnet_by_ref(ref, template_ref, vcenter_uuid, pool = nil)
-        if pool.nil?
-            pool = VCenterDriver::VIHelper.one_pool(OpenNebula::VirtualNetworkPool, false)
-            if pool.respond_to?(:message)
-                raise "Could not get OpenNebula VirtualNetworkPool: #{pool.message}"
-            end
-        end
-        element = pool.select do |e|
-            e["TEMPLATE/VCENTER_NET_REF"]     == ref &&
-            e["TEMPLATE/VCENTER_INSTANCE_ID"] == vcenter_uuid &&
-            e["TEMPLATE/VCENTER_TEMPLATE_REF"] == template_ref &&
-            e["TEMPLATE/OPENNEBULA_MANAGED"] == "NO"
-        end.first rescue nil
-
-        return element
-    end
-
     def self.remove_net_ref(network_id)
         one_vnet = VCenterDriver::VIHelper.one_item(OpenNebula::VirtualNetwork, network_id)
         one_vnet.info
@@ -157,23 +140,6 @@ class Network
         one_vnet.info
     end
 
-    def self.get_unmanaged_vnet_by_ref(ref, template_ref, vcenter_uuid, pool = nil)
-        if pool.nil?
-            pool = VCenterDriver::VIHelper.one_pool(OpenNebula::VirtualNetworkPool, false)
-            if pool.respond_to?(:message)
-                raise "Could not get OpenNebula VirtualNetworkPool: #{pool.message}"
-            end
-        end
-        element = pool.select do |e|
-            e["TEMPLATE/VCENTER_NET_REF"]     == ref &&
-            e["TEMPLATE/VCENTER_INSTANCE_ID"] == vcenter_uuid &&
-            e["TEMPLATE/VCENTER_TEMPLATE_REF"] == template_ref &&
-            e["TEMPLATE/OPENNEBULA_MANAGED"] == "NO"
-        end.first rescue nil
-
-        return element
-    end
-
     # This is never cached
     def self.new_from_ref(ref, vi_client)
         self.new(RbVmomi::VIM::Network.new(vi_client.vim, ref), vi_client)
