@@ -47,7 +47,7 @@ module VNMMAD
                 create_bridge
 
                 # Check that no other vlans are connected to this bridge
-                validate_vlan_id
+                validate_vlan_id if @nic[:conf][:validate_vlan_id]
 
                 # Return if vlan device is already in the bridge.
                 next if @bridges[@nic[:bridge]].include? @nic[:vlan_dev]
@@ -127,11 +127,30 @@ module VNMMAD
 
             OpenNebula.exec_and_log("#{command(:brctl)} addbr #{@nic[:bridge]}")
 
+            set_bridge_options
+
             @bridges[@nic[:bridge]] = Array.new
 
             OpenNebula.exec_and_log("#{command(:ip)} link set #{@nic[:bridge]} up")
         end
 
+        # Calls brctl to set options stored in bridge_conf
+        def set_bridge_options
+            @nic[:bridge_conf].each do |option, value|
+                case value
+                when true
+                    value = "on"
+                when false
+                    value = "off"
+                end
+
+                cmd = "#{command(:brctl)} #{option} " <<
+                        "#{@nic[:bridge]} #{value}"
+
+                OpenNebula.exec_and_log(cmd)
+            end
+        end
+
         # Get hypervisor bridges
         #   @return [Hash<String>] with the bridge names
         def get_bridges
